@@ -105,7 +105,10 @@ def download(source, destination=None, progress_bar=False):
         timeout=HTTP_TIMEOUTS,
     )
     r.raise_for_status()
+    return process_file_response(r, destination, progress_bar)
 
+
+def process_file_response(response, destination, progress_bar=False):
     is_file = False
 
     if destination is None:
@@ -119,12 +122,8 @@ def download(source, destination=None, progress_bar=False):
 
     chunk, chunk_size = 1, 1024
 
-    if progress_bar:
-        for chunk in ProgressBar(r.iter_content(chunk_size)):
-            fp.write(chunk)
-    else:
-        for chunk in r.iter_content(chunk_size):
-            fp.write(chunk)
+    for chunk in tqdm(response.iter_content(chunk_size), leave=False, disable=not progress_bar):
+        fp.write(chunk)
 
     if is_file:
         fp.close()
