@@ -1,11 +1,9 @@
 # coding=utf-8
-import csv
 import datetime
 import json
 import os
 import pathlib
 import time
-from functools import partial
 from multiprocessing.pool import Pool
 from time import sleep
 
@@ -21,9 +19,8 @@ from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_save
 from ..advanced.flows import FileUploadError
 from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException, \
     DuplicateFeatureVectorsException
-from ..constants import RCDB
 from ..providers import AdminProvider, RetailerProvider
-from ..utils import uri_validator, download_and_return_id, get_filename_from_url
+from ..utils import uri_validator, get_filename_from_url
 
 
 @click.group()
@@ -425,52 +422,7 @@ def rcdb_previews_fs(ctx, argument, output, concurrency):
     Prepare previews file structure by the id, filepath or file url of the JSON formatted backup
     Make sure that extension is a valid JSON and extension in the admin is set like that
     """
-    output = pathlib.Path(output).absolute()
-    output.mkdir(parents=True, exist_ok=True)
-
-    filepath = output / "definition.json"
-
-    if argument.isdigit():
-        backup_id = int(argument)
-        rcdb_data = ctx.provider.rcdb.get(backup_id)
-        if rcdb_data['extension'] != RCDB.JSON:
-            click.echo("extension is not supported")  # but we will try anyway
-            # raise click.ClickException("Extension is not supported")
-
-        # download to a local folder
-        remote_loaders.download(rcdb_data['backup'], filepath)
-
-    elif uri_validator(argument):
-        # argument is a url
-        remote_loaders.download(argument, filepath)
-
-    else:
-        filepath = argument
-
-    try:
-        with open(filepath, 'rb') as fp:
-            definition = json.load(fp)
-    except Exception:
-        raise click.ClickException(f"File is not supported. Please check it at {filepath}")
-
-    # apply a script
-    try:
-        import pandas as pd
-        df = pd.DataFrame(definition)
-        df.to_csv(output / "definition.csv", quoting=csv.QUOTE_NONNUMERIC)
-        del df
-    except Exception:
-        pass
-
-    with Pool(concurrency) as pool:
-        for _ in tqdm.tqdm(
-            pool.imap_unordered(partial(download_and_return_id, output=output), definition),
-            desc=f"Downloading images to {str(output)}",
-            total=len(definition),
-        ):
-            pass
-        pool.close()
-        pool.join()
+    click.echo("Use `fvm rcdb unpack` command instead")
 
 
 @api.group()
